@@ -65,7 +65,7 @@ class Hermes:
     #
     key_app    = self.gc.get_string('/apps/maemo/hermes/key_app')
     key_secret = self.gc.get_string('/apps/maemo/hermes/key_secret')
-    if (key_app is None or key_secret is None):
+    if key_app is None or key_secret is None:
       raise Exception('No Facebook application keys found. Installation error.')
 
     self.fb = Facebook(key_app, key_secret)
@@ -91,7 +91,7 @@ class Hermes:
 
     self.gc.set_string('/apps/maemo/hermes/session_key', session['session_key'])
     self.gc.set_string('/apps/maemo/hermes/secret_key', session['secret'])
-    self.gc.set_string('/apps/maemo/hermes/uid', session['uid'])
+    self.gc.set_string('/apps/maemo/hermes/uid', str(session['uid']))
 
 
   # -----------------------------------------------------------------------
@@ -144,11 +144,17 @@ class Hermes:
       (user, passwd) = self.twitter
       api = twitter.Api(username=user, password=passwd)
       users = api.GetFriends()
-      for friend in api.GetFriends():
-        key = unicode(friend.name).encode('trans')
-        url = 'http://twitter.com/%s' % (friend.screen_name)
-        self.friends[key] = {'name': friend.name, 'pic': friend.profile_image_url, 'birthday_date': None, 'twitter_url': url, 'homepage': friend.url, 'account': 'twitter'}
-        self.friends_by_url[url] = self.friends[key]
+      for tweeter in api.GetFriends():
+        key    = unicode(tweeter.name).encode('trans')
+        url    = 'http://twitter.com/%s' % (tweeter.screen_name)
+        friend = {'name':          tweeter.name, 'pic': tweeter.profile_image_url,
+                  'birthday_date': None,         'twitter_url': url,
+                  'homepage':      tweeter.url,  'account': 'twitter'}
+        if friend['pic'].find('/default_profile') > -1:
+          friend['pic'] = None
+          
+        self.friends[key] = friend
+        self.friends_by_url[url] = friend
   
     # TODO What if the user has *no* contacts?
 
